pychemia.code package
=====================

.. automodule:: pychemia.code
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    pychemia.code.abinit
    pychemia.code.dftb
    pychemia.code.fireball
    pychemia.code.lennardjones
    pychemia.code.octopus
    pychemia.code.vasp

Submodules
----------

pychemia.code.codes module
--------------------------

.. automodule:: pychemia.code.codes
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.code.relaxator module
------------------------------

.. automodule:: pychemia.code.relaxator
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.code.tasks module
--------------------------

.. automodule:: pychemia.code.tasks
    :members:
    :undoc-members:
    :show-inheritance:


